==> force-wsc-34.0-sources.jar: com/sforce/ws/codegen/metadata/FactoryClassMetadata.java <==
/*
 * Copyright (c) 2013, salesforce.com, inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *    Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *    following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *    Neither the name of salesforce.com, inc. nor the names of its contributors may be used to endorse or
 *    promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.sforce.ws.codegen.metadata;

import com.sforce.ws.codegen.TypeMetadataConstructor;

import java.util.List;

/**
 * @author sweiss
 * @since 192
 */
public class FactoryClassMetadata extends ClassMetadata {
    private final List<ClassMetadata> types;
    private final ClassMetadata sObjectClass;

    public FactoryClassMetadata(String packageName, String className, List<ClassMetadata> types, ClassMetadata sObjectClass, String interfacePackageName) {
        super(packageName, className, interfacePackageName);
        this.types = types;
        this.sObjectClass = sObjectClass;
    }

    public List<ClassMetadata> getTypes() {
        return types;
    }

    public ClassMetadata getSObjectClass() {
        return sObjectClass;
    }

    public boolean getHasSObjectClass() {
        return sObjectClass != null;
    }
}

==> force-wsc-65.0.0-sources.jar: com/sforce/ws/codegen/metadata/FactoryClassMetadata.java <==
/*
 * Copyright (c) 2017, salesforce.com, inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *    Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *    following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *    Neither the name of salesforce.com, inc. nor the names of its contributors may be used to endorse or
 *    promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.sforce.ws.codegen.metadata;

import com.sforce.ws.codegen.TypeMetadataConstructor;

import java.util.List;

/**
 * @author sweiss
 * @since 192
 */
public class FactoryClassMetadata extends ClassMetadata {
    private final List<ClassMetadata> types;
    private final ClassMetadata sObjectClass;

    public FactoryClassMetadata(String packageName, String className, List<ClassMetadata> types, ClassMetadata sObjectClass, String interfacePackageName, boolean addDeprecatedAnnotation) {
        super(packageName, className, interfacePackageName, addDeprecatedAnnotation);
        this.types = types;
        this.sObjectClass = sObjectClass;
    }

    public List<ClassMetadata> getTypes() {
        return types;
    }

    public ClassMetadata getSObjectClass() {
        return sObjectClass;
    }

    public boolean getHasSObjectClass() {
        return sObjectClass != null;
    }
}
